@@ -37,17 +37,19 @@ object_data = {
     'VIFGeneric': '1.0-c72e637ed620f0135ea50a9409a3f389',
     'VIFHostDevice': '1.0-bb090f1869c3b4df36efda216ab97a61',
     'VIFOpenVSwitch': '1.0-e78d355f3505361fafbf0797ffad484a',
-    'VIFPortProfile8021Qbg': '1.0-167f305f6e982b9368cc38763815d429',
-    'VIFPortProfile8021Qbh': '1.0-4b945f07d2666ab00a48d1dc225669b1',
-    'VIFPortProfileBase': '1.0-77509ea1ea0dd750d5864b9bd87d3f9d',
-    'VIFPortProfileOpenVSwitch': '1.1-70d36e09c8d800345ce71177265212df',
-    'VIFPortProfileFPOpenVSwitch': '1.1-74e77f46aa5806930df6f37a0b76ff8b',
-    'VIFPortProfileFPBridge': '1.0-d50872b3cddd245ffebef6053dfbe27a',
-    'VIFPortProfileFPTap': '1.0-11670d8dbabd772ff0da26961adadc5a',
+    'VIFPortProfile8021Qbg': '1.1-b3011621809dca9216b50579ce9d6b19',
+    'VIFPortProfile8021Qbh': '1.1-226b61b2e76ba452f7b31530cff80ac9',
+    'VIFPortProfileBase': '1.1-4982d1621df12ebd1f3b07948f3d0e5f',
+    'VIFPortProfileOpenVSwitch': '1.2-25aec86b7ec9fcb3434f896f694818de',
+    'VIFPortProfileFPOpenVSwitch': '1.2-4a4f230d89a5ea0e43011f678b626dd9',
+    'VIFPortProfileFPBridge': '1.1-49f1952bf50bab7a95112c908534751f',
+    'VIFPortProfileFPTap': '1.1-fd178229477604dfb65de5ce929488e5',
     'VIFVHostUser': '1.1-1f95b43be1f884f090ca1f4d79adfd35',
-    'VIFPortProfileOVSRepresentor': '1.1-30e555981003a109b133da5b43ded5df',
+    'VIFPortProfileOVSRepresentor': '1.2-d0609e93ea884ef7b4949177e9fcdc39',
     'VIFNestedDPDK': '1.0-fdbaf6b20afd116529929b21aa7158dc',
-    'VIFPortProfileK8sDPDK': '1.0-f1e0daa66b041ded4e6dbc053b4a66d5',
+    'VIFPortProfileK8sDPDK': '1.1-e2a2abd112b14e0239e76b99d9b252ae',
+    'DatapathOffloadBase': '1.0-77509ea1ea0dd750d5864b9bd87d3f9d',
+    'DatapathOffloadRepresentor': '1.0-802a5dff22f73046df3742c815c51421',
 }
 
 
